"use strict";

// Works similarly to webpack-node-externals but it's not as
// aggressive. It only excludes top-level dependency-declared
// modules. Respects an `allowList` of regexp's that will be
// used to match modules to include in the bundle.
var _require = require('kyt-utils/paths')(),
  userPackageJSONPath = _require.userPackageJSONPath;
var pkg;
try {
  // eslint-disable-next-line import/no-dynamic-require, global-require
  pkg = require(userPackageJSONPath);
} catch (e) {
  pkg = {};
}
module.exports = function () {
  var allowList = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  // Get all of the dependencies from the package.json
  // and filter out the ones that are in the allowList
  var packageModules = [];
  Object.keys(pkg.dependencies || []).forEach(function (module) {
    allowList.forEach(function (allowedModule) {
      if (!allowedModule.test(module)) packageModules.push(module);
    });
  });
  return [
  // eslint-disable-next-line consistent-return
  function (context, request, callback) {
    function getModuleName(requested) {
      var scopedModuleRegex = new RegExp('@[a-zA-Z0-9][\\w-.]+/[a-zA-Z0-9][\\w-.]+([a-zA-Z0-9./]+)?', 'g');
      var req = requested;
      var delimiter = '/';

      // Check if scoped module. For example: @company/boring-module
      if (scopedModuleRegex.test(req)) {
        // reset regexp
        scopedModuleRegex.lastIndex = 0;
        return req.split(delimiter, 2).join(delimiter);
      }
      return req.split(delimiter)[0];
    }
    if (packageModules.includes(getModuleName(request))) {
      // Mark this module as EXTERNAL
      return callback(null, "commonjs ".concat(request));
    }
    // Include module in bundle / NOT EXTERNAL
    callback();
  }];
};